package net;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.net.SocketException;

public class LineSocket {
  InputStream is;
  OutputStream os;
  Socket s;
  String socketName;
  
  
  public LineSocket() {
  }

  public LineSocket(String socketName) {
    this.socketName = socketName;
  }

  public void showVerbose(String string) {
    if (socketName==null){
      System.err.println(string);
    } else {
      System.err.println(socketName+":"+string);
    }
  }

  /**
   * Test if the message is complete (contains a terminal character)
   */
  public boolean isComplete(String result) {
    return result.endsWith(messageTerminator);
  }


  static String serverName = "localhost";
  static int serverPort = 5000;

  public void openConnection() throws IOException{
    s = new Socket();
    InetSocketAddress addr = new InetSocketAddress(serverName, serverPort);
    s.connect(addr);
    is = s.getInputStream();
    os = s.getOutputStream();
  }
  
  
  public void openConnection(Socket s) throws IOException{
    this.s = s;
    is = s.getInputStream();
    os = s.getOutputStream();
  }
  



  /**
   * The current message terminator is CR LF (13 10).
   */
  public static final String messageTerminator = "" + ((char) 13) + ((char) 10);

  public void openStreams() throws IOException{
    assert(s!=null && s.isConnected());
    is = s.getInputStream();
    os = s.getOutputStream();
  }
  
  
  public void closeConnection() throws IOException{
    is.close();
    os.close();
    s.close();
  }
  
  
  
  /**
   * Send a message to the server. Appends a message terminator (period).
   */
  public synchronized void sendMessage(String message) throws SocketException,
      IOException {
    showVerbose("SENDS:" + message);
    message = message + messageTerminator;
    byte[] messageData = message.getBytes();
    os.write(messageData);
  }

  /**
   * Receive a message from the server. Removes a message terminator (period).
   */
  public String receiveMessage() throws SocketException, IOException {
    String response = "";
    do {
      char c = (char) (is.read());
      // System.out.println("READ:"+(int)c);
      response = response + c;

    } while (!isComplete(response));
    response = response.substring(0, response.length()
        - messageTerminator.length());
    showVerbose("RECEIVES:" + response);
    return response;
  }


}
