package stats;

import util.Array;
import game.GameObserver;
import game.Utility;


/**
 * An observer of utility, like jointactionutility, that does
 * not keep track of joint actions, simply utilities.
 * @author maz
 *
 */
public class UtilityObserver implements GameObserver{
  /**
   * The utility function.
   */
  Utility utility;
  
  /**
   * The total utilities up until now.
   */
  int[] utilityTotals;
  
  /**
   * The last recorded utility.
   */
  int[] lastUtility;
  
  /**
   * Construct a utility observer.
   * @param utility a utility function to be used.
   * @param numPlayers the number of players in the game.
   */
  public UtilityObserver(Utility utility, int numPlayers){
    this.utility = utility;
    utilityTotals = new int[numPlayers];
    lastUtility=new int[numPlayers];
  }
  
  @Override
  public void observeOutcome(int[] actions) {
    utility.getUtility(actions,lastUtility);
    for(int i=0;i<lastUtility.length;i++){
      utilityTotals[i]+=lastUtility[i];
    }
  }
  
  /**
   * Display the utilities. Format is a naked string.
   */
  public void display() {
    System.out.println(Array.arrayToString(utilityTotals));
    
  }
  public int[] getUtilities() {
    return utilityTotals;
  }
}
